@@ -8,7 +8,7 @@
  *
  * Copyright (C) 2006-2009 by Valerio Fuoglio <valerio dot fuoglio at gmail dot com>
  * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -50,7 +50,7 @@ namespace KIPIAdvancedSlideshowPlugin
 
 class SlideShowLoader;
 class SlidePlaybackWidget;
-class SharedData;
+class SharedContainer;
 class PlaybackWidget;
 
 class SlideShow : public QWidget
@@ -61,7 +61,7 @@ class SlideShow : public QWidget
 
 public:
 
-    SlideShow(const FileList& fileList, const QStringList& commentsList, SharedData* sharedData);
+    SlideShow(const FileList& fileList, const QStringList& commentsList, SharedContainer* sharedData);
     ~SlideShow();
 
     void registerEffects();
@@ -69,7 +69,6 @@ public:
     static QStringList            effectNames();
     static QMap<QString, QString> effectNamesI18N();
 
-
 protected:
 
     void    mousePressEvent(QMouseEvent *event);
@@ -122,14 +121,13 @@ private:
     void         printProgress();
     void         showEndOfShow();
     void         readSettings();
-
     EffectMethod getRandomEffect();
 
 private:
 
-    SharedData*  m_sharedData;
+    SharedContainer*            m_sharedData;
 
-    uint         m_cacheSize;
+    uint                        m_cacheSize;
 
     // -------------------------
 
