@@ -39,6 +39,7 @@
 
 // KDE includes
 
+#include <kdebug.h>
 #include <kdialog.h>
 #include <kiconloader.h>
 #include <klocale.h>
@@ -68,6 +69,8 @@ const int DEFAULTSIZE = KIconLoader::SizeLarge;
 ImagesListViewItem::ImagesListViewItem(ImagesListView *view, const KUrl& url)
                   : QTreeWidgetItem(view)
 {
+    kDebug() << "Creating new ImageListViewItem with url " << url
+             << " for list view " << view;
     m_view       = view;
     int iconSize = m_view->iconSize().width();
     setThumb(SmallIcon("image-x-generic", iconSize, KIconLoader::DisabledState));
@@ -146,6 +149,15 @@ int ImagesListViewItem::rating()
 
 void ImagesListViewItem::setThumb(const QPixmap& pix)
 {
+    kDebug() << "Received new thumbnail for url " << m_url
+             << ". My view is " << m_view;
+    if (!m_view)
+    {
+        kError() << "This item doesn't have a tree view. "
+                 << "This should never happen!";
+        return;
+    }
+
     int iconSize = qMax<int>(m_view->iconSize().width(), m_view->iconSize().height());
     QPixmap pixmap(iconSize+2, iconSize+2);
     pixmap.fill(Qt::transparent);
@@ -173,6 +185,12 @@ void ImagesListViewItem::setProcessedIcon(const QIcon& icon)
     setIcon(ImagesListView::Thumbnail, QIcon(m_thumb));
 }
 
+
+ImagesListView* ImagesListViewItem::view()
+{
+    return m_view;
+}
+
 // ---------------------------------------------------------------------------
 
 ImagesListView::ImagesListView(ImagesList *parent)
@@ -515,9 +533,9 @@ void ImagesList::setControlButtonsPlacement(ControlButtonPlacement placement)
     QHBoxLayout *hBtnLayout = new QHBoxLayout;
     hBtnLayout->addStretch(10);
     hBtnLayout->addWidget(d->moveUpButton);
+    hBtnLayout->addWidget(d->moveDownButton);
     hBtnLayout->addWidget(d->addButton);
     hBtnLayout->addWidget(d->removeButton);
-    hBtnLayout->addWidget(d->moveDownButton);
     hBtnLayout->addWidget(d->loadButton);
     hBtnLayout->addWidget(d->saveButton);
     hBtnLayout->addWidget(d->clearButton);
@@ -528,9 +546,9 @@ void ImagesList::setControlButtonsPlacement(ControlButtonPlacement placement)
     QVBoxLayout *vBtnLayout = new QVBoxLayout;
     vBtnLayout->addStretch(10);
     vBtnLayout->addWidget(d->moveUpButton);
+    vBtnLayout->addWidget(d->moveDownButton);
     vBtnLayout->addWidget(d->addButton);
     vBtnLayout->addWidget(d->removeButton);
-    vBtnLayout->addWidget(d->moveDownButton);
     vBtnLayout->addWidget(d->loadButton);
     vBtnLayout->addWidget(d->saveButton);
     vBtnLayout->addWidget(d->clearButton);
@@ -697,7 +715,7 @@ void ImagesList::slotThumbnail(const KUrl& url, const QPixmap& pix)
     while (*it)
     {
         ImagesListViewItem* item = dynamic_cast<ImagesListViewItem*>(*it);
-        if (item->url() == url)
+        if (item && item->url() == url)
         {
             if (pix.isNull())
                 item->setThumb(SmallIcon("image-x-generic", d->iconSize, KIconLoader::DisabledState));
@@ -734,6 +752,7 @@ void ImagesList::slotRemoveItems()
 
 void ImagesList::slotMoveUpItems()
 {
+    // move above item down, then we don't have to fix the focus
     QModelIndex curIndex = listView()->currentIndex();
     if (!curIndex.isValid())
         return;
@@ -744,12 +763,15 @@ void ImagesList::slotMoveUpItems()
 
     QTreeWidgetItem* temp = listView()->takeTopLevelItem(aboveIndex.row());
     listView()->insertTopLevelItem(curIndex.row(), temp);
+    // this is a quick fix. We loose the extra tags in flickr upload, but at list we don't get a crash
+    dynamic_cast<KIPIPlugins::ImagesListViewItem*>(temp)->updateItemWidgets();
 
     emit signalImageListChanged();
 }
 
 void ImagesList::slotMoveDownItems()
 {
+    // move below item up, then we don't have to fix the focus
     QModelIndex curIndex = listView()->currentIndex();
     if (!curIndex.isValid())
         return;
@@ -760,6 +782,8 @@ void ImagesList::slotMoveDownItems()
 
     QTreeWidgetItem* temp = listView()->takeTopLevelItem(belowIndex.row());
     listView()->insertTopLevelItem(curIndex.row(), temp);
+    // this is a quick fix. We loose the extra tags in flickr upload, but at list we don't get a crash
+    dynamic_cast<KIPIPlugins::ImagesListViewItem*>(temp)->updateItemWidgets();
 
     emit signalImageListChanged();
 }
