@@ -57,10 +57,6 @@
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
 
-#if KDCRAW_VERSION < 0x000400
-#include <libkdcraw/dcrawbinary.h>
-#endif
-
 // Local includes
 
 #include "batchprogressdialog.h"
@@ -401,11 +397,7 @@ bool SimpleViewer::exportImages()
             d->progressDlg->addedAction(i18n("Processing %1", url.fileName()), KIPIPlugins::StartingMessage);
 
             // Check if RAW file.
-#if KDCRAW_VERSION < 0x000400
-            QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
-#else
             QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-#endif
             if (rawFilesExt.toUpper().contains( fi.suffix().toUpper()))
                 KDcrawIface::KDcraw::loadDcrawPreview(image, url.path());
             else
