@@ -53,7 +53,6 @@
 #include <krun.h>
 #include <ktoolinvocation.h>
 #include <kurllabel.h>
-#include <ktoolinvocation.h>
 #include <kstandarddirs.h>
 
 // LibKIPI includes
@@ -666,7 +665,7 @@ void GalleryWindow::slotNewAlbum()
 
     if (!clean)
     {
-        KMessageBox::error(this, i18n("Sorry, these characters are not allowed in album name: \\ / * ? \" \' & < > | . + # ( ) or spaces"));
+        KMessageBox::error(this, i18n("Sorry, these characters are not allowed in album name: \\ / * ? \" \' & &lt; &gt; | . + # ( ) or spaces"));
         return;
     }
 
