@@ -9,6 +9,7 @@
  * Copyright (C) 2007-2008 by Vardhman Jain <vardhman at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  * Copyright (C) 2010 by Jens Mueller <tschenser at gmx dot de>
+ * Copyright (C) 2010 by Caulier Gilles <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,7 +23,6 @@
  *
  * ============================================================ */
 
-#include "picasawebwidget.h"
 #include "picasawebwidget.moc"
 
 // Qt includes
@@ -31,6 +31,7 @@
 #include <QSpinBox>
 #include <QCheckBox>
 #include <QGroupBox>
+#include <QButtonGroup>
 #include <QRadioButton>
 #include <QProgressBar>
 #include <QGridLayout>
@@ -45,20 +46,13 @@
 #include <KComboBox>
 #include <KPushButton>
 
-// LibKIPI includes
-
-#include <libkipi/interface.h>
-#include <libkipi/uploadwidget.h>
-
-// Local includes
-
-#include "imageslist.h"
+#include "picasawebimglist.h"
 
 namespace KIPIPicasawebExportPlugin
 {
 
-PicasawebWidget::PicasawebWidget(QWidget* parent, KIPI::Interface *iface, bool import)
-        : QWidget(parent)
+PicasawebWidget::PicasawebWidget(QWidget* parent, Interface* iface, bool import)
+               : QWidget(parent)
 {
     setObjectName("PicasawebWidget");
 
@@ -66,8 +60,8 @@ PicasawebWidget::PicasawebWidget(QWidget* parent, KIPI::Interface *iface, bool i
 
     // -------------------------------------------------------------------
 
-    m_imgList  = new KIPIPlugins::ImagesList(iface, this);
-    m_imgList->setControlButtonsPlacement(KIPIPlugins::ImagesList::ControlButtonsBelow);
+    m_imgList  = new PicasawebImagesList(iface, this);
+    m_imgList->setControlButtonsPlacement(ImagesList::ControlButtonsBelow);
     m_imgList->setAllowRAW(true);
     m_imgList->loadImagesFromCurrentSelection();
     m_imgList->listView()->setWhatsThis(
@@ -103,11 +97,11 @@ PicasawebWidget::PicasawebWidget(QWidget* parent, KIPI::Interface *iface, bool i
         KGuiItem(i18n("Change Account"), "system-switch-user",
                  i18n("Change Picasaweb Account used to authenticate")), accountBox);
 
-    accountBoxLayout->addWidget(m_anonymousRBtn,        0, 0, 1, 2);
-    accountBoxLayout->addWidget(m_accountRBtn,          1, 0, 1, 2);
-    accountBoxLayout->addWidget(m_userNameLbl,          2, 0, 1, 1);
-    accountBoxLayout->addWidget(m_userName,             2, 1, 1, 1);
-    accountBoxLayout->addWidget(m_changeUserBtn,        3, 1, 1, 1);
+    accountBoxLayout->addWidget(m_anonymousRBtn, 0, 0, 1, 2);
+    accountBoxLayout->addWidget(m_accountRBtn,   1, 0, 1, 2);
+    accountBoxLayout->addWidget(m_userNameLbl,   2, 0, 1, 1);
+    accountBoxLayout->addWidget(m_userName,      2, 1, 1, 1);
+    accountBoxLayout->addWidget(m_changeUserBtn, 3, 1, 1, 1);
     accountBoxLayout->setSpacing(KDialog::spacingHint());
     accountBoxLayout->setMargin(KDialog::spacingHint());
 
@@ -128,9 +122,9 @@ PicasawebWidget::PicasawebWidget(QWidget* parent, KIPI::Interface *iface, bool i
             KGuiItem(i18nc("reload album list", "Reload"), "view-refresh",
                      i18n("Reload album list")), accountBox);
 
-    albumsBoxLayout->addWidget(m_albumsCoB,         0, 0, 1, 5);
-    albumsBoxLayout->addWidget(m_newAlbumBtn,       1, 3, 1, 1);
-    albumsBoxLayout->addWidget(m_reloadAlbumsBtn,   1, 4, 1, 1);
+    albumsBoxLayout->addWidget(m_albumsCoB,       0, 0, 1, 5);
+    albumsBoxLayout->addWidget(m_newAlbumBtn,     1, 3, 1, 1);
+    albumsBoxLayout->addWidget(m_reloadAlbumsBtn, 1, 4, 1, 1);
 
     // ------------------------------------------------------------------------
 
@@ -169,12 +163,35 @@ PicasawebWidget::PicasawebWidget(QWidget* parent, KIPI::Interface *iface, bool i
     m_imageQualitySpB->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     QLabel* imageQualityLbl = new QLabel(i18n("JPEG quality:"), optionsBox);
 
-    optionsBoxLayout->addWidget(m_resizeChB,        0, 0, 1, 5);
-    optionsBoxLayout->addWidget(imageQualityLbl,    1, 1, 1, 1);
-    optionsBoxLayout->addWidget(m_imageQualitySpB,  1, 2, 1, 1);
-    optionsBoxLayout->addWidget(dimensionLbl,       2, 1, 1, 1);
-    optionsBoxLayout->addWidget(m_dimensionSpB,     2, 2, 1, 1);
-    optionsBoxLayout->setRowStretch(3, 10);
+    QSpacerItem* spacer = new QSpacerItem(1, 10, QSizePolicy::Expanding, QSizePolicy::Minimum);
+    QLabel* tagsLbl = new QLabel(i18n("Tag path behavior:"), optionsBox);
+
+    QRadioButton* leafTagsBtn = new QRadioButton(i18n("Leaf tags only"), optionsBox);
+    leafTagsBtn->setWhatsThis(
+        i18n("Export only the leaf tags of tag hierarchies"));
+    QRadioButton* splitTagsBtn = new QRadioButton(i18n("Split tags"), optionsBox);
+    splitTagsBtn->setWhatsThis(
+        i18n("Export the leaf tag and all ancestors as single tags."));
+    QRadioButton* combinedTagsBtn  = new QRadioButton(i18n("Combined String"), optionsBox);
+    combinedTagsBtn->setWhatsThis(
+        i18n("Build a combined tag string."));
+
+    m_tagsBGrp = new QButtonGroup(optionsBox);
+    m_tagsBGrp->addButton(leafTagsBtn, PwTagLeaf);
+    m_tagsBGrp->addButton(splitTagsBtn, PwTagSplit);
+    m_tagsBGrp->addButton(combinedTagsBtn, PwTagCombined);
+
+    optionsBoxLayout->addWidget(m_resizeChB,       0, 0, 1, 5);
+    optionsBoxLayout->addWidget(imageQualityLbl,   1, 1, 1, 1);
+    optionsBoxLayout->addWidget(m_imageQualitySpB, 1, 2, 1, 1);
+    optionsBoxLayout->addWidget(dimensionLbl,      2, 1, 1, 1);
+    optionsBoxLayout->addWidget(m_dimensionSpB,    2, 2, 1, 1);
+    optionsBoxLayout->addItem(spacer,              3, 0, 1, 5);
+    optionsBoxLayout->addWidget(tagsLbl,           4, 0, 1, 5);
+    optionsBoxLayout->addWidget(leafTagsBtn,       5, 1, 1, 4);
+    optionsBoxLayout->addWidget(splitTagsBtn,      6, 1, 1, 4);
+    optionsBoxLayout->addWidget(combinedTagsBtn,   7, 1, 1, 4);
+    optionsBoxLayout->setRowStretch(8, 10);
     optionsBoxLayout->setSpacing(KDialog::spacingHint());
     optionsBoxLayout->setMargin(KDialog::spacingHint());
 
@@ -237,7 +254,7 @@ PicasawebWidget::~PicasawebWidget()
 {
 }
 
-KIPIPlugins::ImagesList* PicasawebWidget::imagesList() const
+ImagesList* PicasawebWidget::imagesList() const
 {
     return m_imgList;
 }
@@ -255,9 +272,9 @@ QString PicasawebWidget::getDestinationPath()
 void PicasawebWidget::updateLabels(const QString& name)
 {
     m_userName->setText(QString("<b>%1</b>").arg(name));
-    m_headerLbl->setText(QString("<b><h2><a href='http://picasaweb.google.de/%1'>"
-                                   "<font color=\"#9ACD32\">Picasaweb</font>"
-                                   "</a></h2></b>").arg(name));
+    m_headerLbl->setText(QString("<b><h2><a href='http://picasaweb.google.com/%1'>"
+                                 "<font color=\"#9ACD32\">Picasaweb</font>"
+                                 "</a></h2></b>").arg(name));
 }
 
 void PicasawebWidget::slotChangeUserClicked()
