@@ -77,7 +77,7 @@ extern "C"
 #include "actionthread.h"
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
-#include "previewimage.h"
+#include "previewmanager.h"
 #include "rawdecodingiface.h"
 #include "savesettingswidget.h"
 
@@ -105,7 +105,7 @@ public:
 
     KUrl                 inputFile;
 
-    PreviewImage*        previewWidget;
+    PreviewManager*      previewWidget;
 
     ActionThread*        thread;
 
@@ -134,12 +134,12 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
     setMainWidget( page );
     QGridLayout *mainLayout = new QGridLayout(page);
 
-    d->previewWidget        = new PreviewImage(page);
+    d->previewWidget        = new PreviewManager(page);
 
     // ---------------------------------------------------------------
 
-    d->decodingSettingsBox  = new DcrawSettingsWidget(page, DcrawSettingsWidget::SIXTEENBITS |
-                                                            DcrawSettingsWidget::COLORSPACE |
+    d->decodingSettingsBox  = new DcrawSettingsWidget(page, DcrawSettingsWidget::SIXTEENBITS    |
+                                                            DcrawSettingsWidget::COLORSPACE     |
                                                             DcrawSettingsWidget::POSTPROCESSING |
                                                             DcrawSettingsWidget::BLACKWHITEPOINTS);
     d->saveSettingsBox      = new SaveSettingsWidget(d->decodingSettingsBox);
@@ -168,7 +168,7 @@ SingleDialog::SingleDialog(const QString& file, KIPI::Interface* iface)
                    KAboutData::License_GPL,
                    ki18n("A Kipi plugin to convert RAW images"),
                    ki18n("(c) 2003-2005, Renchi Raju\n"
-                         "(c) 2006-2009, Gilles Caulier"));
+                         "(c) 2006-2010, Gilles Caulier"));
 
     d->about->addAuthor(ki18n("Renchi Raju"),
                        ki18n("Author"),
@@ -266,7 +266,7 @@ void SingleDialog::slotSixteenBitsImageToggled(bool)
     d->decodingSettingsBox->setEnabledBrightnessSettings(true);
 }
 
-void SingleDialog::closeEvent(QCloseEvent *e)
+void SingleDialog::closeEvent(QCloseEvent* e)
 {
     if (!e) return;
     d->thread->cancel();
@@ -283,8 +283,8 @@ void SingleDialog::slotClose()
 
 void SingleDialog::slotDefault()
 {
-    d->decodingSettingsBox->setDefaultSettings();
-    d->saveSettingsBox->setDefaultSettings();
+    d->decodingSettingsBox->resetToDefault();
+    d->saveSettingsBox->resetToDefault();
 }
 
 void SingleDialog::readSettings()
@@ -292,40 +292,9 @@ void SingleDialog::readSettings()
     KConfig config("kipirc");
     KConfigGroup group = config.group(QString("RawConverter Settings"));
 
-    d->decodingSettingsBox->setSixteenBits(group.readEntry("Sixteen Bits", false));
-    d->decodingSettingsBox->setWhiteBalance((KDcrawIface::RawDecodingSettings::WhiteBalance)
-                                            group.readEntry("White Balance",
-                                            (int)KDcrawIface::RawDecodingSettings::CAMERA));
-    d->decodingSettingsBox->setCustomWhiteBalance(group.readEntry("Custom White Balance", 6500));
-    d->decodingSettingsBox->setCustomWhiteBalanceGreen(group.readEntry("Custom White Balance Green", 1.0));
-    d->decodingSettingsBox->setFourColor(group.readEntry("Four Color RGB", false));
-    d->decodingSettingsBox->setUnclipColor(group.readEntry("Unclip Color", 0));
-    d->decodingSettingsBox->setDontStretchPixels(group.readEntry("Dont Stretch Pixels", false));
-    d->decodingSettingsBox->setNoiseReduction(group.readEntry("Use Noise Reduction", false));
-    d->decodingSettingsBox->setBrightness(group.readEntry("Brightness Multiplier", 1.0));
-    d->decodingSettingsBox->setUseBlackPoint(group.readEntry("Use Black Point", false));
-    d->decodingSettingsBox->setBlackPoint(group.readEntry("Black Point", 0));
-    d->decodingSettingsBox->setUseWhitePoint(group.readEntry("Use White Point", false));
-    d->decodingSettingsBox->setWhitePoint(group.readEntry("White Point", 0));
-    d->decodingSettingsBox->setMedianFilterPasses(group.readEntry("Median Filter Passes", 0));
-    d->decodingSettingsBox->setNRThreshold(group.readEntry("NR Threshold", 100));
-    d->decodingSettingsBox->setUseCACorrection(group.readEntry("EnableCACorrection", false));
-    d->decodingSettingsBox->setcaRedMultiplier(group.readEntry("caRedMultiplier", 1.0));
-    d->decodingSettingsBox->setcaBlueMultiplier(group.readEntry("caBlueMultiplier", 1.0));
-#if KDCRAW_VERSION >= 0x000500
-    d->decodingSettingsBox->setAutoBrightness(group.readEntry("AutoBrightness", true));
-#endif
-
-    d->decodingSettingsBox->setQuality(
-        (KDcrawIface::RawDecodingSettings::DecodingQuality)group.readEntry("Decoding Quality",
-            (int)(KDcrawIface::RawDecodingSettings::BILINEAR)));
-
-    d->decodingSettingsBox->setOutputColorSpace(
-        (KDcrawIface::RawDecodingSettings::OutputColorSpace)group.readEntry("Output Color Space",
-            (int)(KDcrawIface::RawDecodingSettings::SRGB)));
-
+    d->decodingSettingsBox->readSettings(group);
     d->saveSettingsBox->readSettings(group);
-    d->saveSettingsBox->slotPopulateImageFormat(d->decodingSettingsBox->sixteenBits());
+    d->saveSettingsBox->slotPopulateImageFormat(d->decodingSettingsBox->settings().sixteenBitsImage);
 
     KConfigGroup group2 = config.group(QString("Single Raw Converter Dialog"));
     restoreDialogSize(group2);
@@ -336,30 +305,7 @@ void SingleDialog::saveSettings()
     KConfig config("kipirc");
     KConfigGroup group = config.group(QString("RawConverter Settings"));
 
-    group.writeEntry("Sixteen Bits", d->decodingSettingsBox->sixteenBits());
-    group.writeEntry("White Balance", (int)d->decodingSettingsBox->whiteBalance());
-    group.writeEntry("Custom White Balance", d->decodingSettingsBox->customWhiteBalance());
-    group.writeEntry("Custom White Balance Green", d->decodingSettingsBox->customWhiteBalanceGreen());
-    group.writeEntry("Four Color RGB", d->decodingSettingsBox->useFourColor());
-    group.writeEntry("Unclip Color", d->decodingSettingsBox->unclipColor());
-    group.writeEntry("Dont Stretch Pixels", d->decodingSettingsBox->useDontStretchPixels());
-    group.writeEntry("Use Noise Reduction", d->decodingSettingsBox->useNoiseReduction());
-    group.writeEntry("Brightness Multiplier", d->decodingSettingsBox->brightness());
-    group.writeEntry("Use Black Point", d->decodingSettingsBox->useBlackPoint());
-    group.writeEntry("Black Point", d->decodingSettingsBox->blackPoint());
-    group.writeEntry("Use White Point", d->decodingSettingsBox->useWhitePoint());
-    group.writeEntry("White Point", d->decodingSettingsBox->whitePoint());
-    group.writeEntry("Median Filter Passes", d->decodingSettingsBox->medianFilterPasses());
-    group.writeEntry("NR Threshold", d->decodingSettingsBox->NRThreshold());
-    group.writeEntry("EnableCACorrection", d->decodingSettingsBox->useCACorrection());
-    group.writeEntry("caRedMultiplier", d->decodingSettingsBox->caRedMultiplier());
-    group.writeEntry("caBlueMultiplier", d->decodingSettingsBox->caBlueMultiplier());
-    group.writeEntry("Decoding Quality", (int)d->decodingSettingsBox->quality());
-    group.writeEntry("Output Color Space", (int)d->decodingSettingsBox->outputColorSpace());
-#if KDCRAW_VERSION >= 0x000500
-    group.writeEntry("AutoBrightness", d->decodingSettingsBox->useAutoBrightness());
-#endif
-
+    d->decodingSettingsBox->writeSettings(group);
     d->saveSettingsBox->writeSettings(group);
 
     KConfigGroup group2 = config.group(QString("Single Raw Converter Dialog"));
@@ -370,32 +316,7 @@ void SingleDialog::saveSettings()
 // 'Preview' dialog button.
 void SingleDialog::slotUser1()
 {
-    KDcrawIface::RawDecodingSettings rawDecodingSettings;
-    rawDecodingSettings.sixteenBitsImage           = d->decodingSettingsBox->sixteenBits();
-    rawDecodingSettings.whiteBalance               = d->decodingSettingsBox->whiteBalance();
-    rawDecodingSettings.customWhiteBalance         = d->decodingSettingsBox->customWhiteBalance();
-    rawDecodingSettings.customWhiteBalanceGreen    = d->decodingSettingsBox->customWhiteBalanceGreen();
-    rawDecodingSettings.RGBInterpolate4Colors      = d->decodingSettingsBox->useFourColor();
-    rawDecodingSettings.unclipColors               = d->decodingSettingsBox->unclipColor();
-    rawDecodingSettings.DontStretchPixels          = d->decodingSettingsBox->useDontStretchPixels();
-    rawDecodingSettings.enableNoiseReduction       = d->decodingSettingsBox->useNoiseReduction();
-    rawDecodingSettings.brightness                 = d->decodingSettingsBox->brightness();
-    rawDecodingSettings.enableBlackPoint           = d->decodingSettingsBox->useBlackPoint();
-    rawDecodingSettings.blackPoint                 = d->decodingSettingsBox->blackPoint();
-    rawDecodingSettings.enableWhitePoint           = d->decodingSettingsBox->useWhitePoint();
-    rawDecodingSettings.whitePoint                 = d->decodingSettingsBox->whitePoint();
-    rawDecodingSettings.medianFilterPasses         = d->decodingSettingsBox->medianFilterPasses();
-    rawDecodingSettings.NRThreshold                = d->decodingSettingsBox->NRThreshold();
-    rawDecodingSettings.enableCACorrection         = d->decodingSettingsBox->useCACorrection();
-    rawDecodingSettings.caMultiplier[0]            = d->decodingSettingsBox->caRedMultiplier();
-    rawDecodingSettings.caMultiplier[1]            = d->decodingSettingsBox->caBlueMultiplier();
-    rawDecodingSettings.RAWQuality                 = d->decodingSettingsBox->quality();
-    rawDecodingSettings.outputColorSpace           = d->decodingSettingsBox->outputColorSpace();
-#if KDCRAW_VERSION >= 0x000500
-        rawDecodingSettings.autoBrightness         = d->decodingSettingsBox->useAutoBrightness();
-#endif
-
-    d->thread->setRawDecodingSettings(rawDecodingSettings, SaveSettingsWidget::OUTPUT_PNG);
+    d->thread->setRawDecodingSettings(d->decodingSettingsBox->settings(), SaveSettingsWidget::OUTPUT_PNG);
     d->thread->processHalfRawFile(KUrl(d->inputFile));
     if (!d->thread->isRunning())
         d->thread->start();
@@ -404,32 +325,7 @@ void SingleDialog::slotUser1()
 // 'Convert' dialog button.
 void SingleDialog::slotUser2()
 {
-    KDcrawIface::RawDecodingSettings rawDecodingSettings;
-    rawDecodingSettings.sixteenBitsImage           = d->decodingSettingsBox->sixteenBits();
-    rawDecodingSettings.whiteBalance               = d->decodingSettingsBox->whiteBalance();
-    rawDecodingSettings.customWhiteBalance         = d->decodingSettingsBox->customWhiteBalance();
-    rawDecodingSettings.customWhiteBalanceGreen    = d->decodingSettingsBox->customWhiteBalanceGreen();
-    rawDecodingSettings.RGBInterpolate4Colors      = d->decodingSettingsBox->useFourColor();
-    rawDecodingSettings.unclipColors               = d->decodingSettingsBox->unclipColor();
-    rawDecodingSettings.DontStretchPixels          = d->decodingSettingsBox->useDontStretchPixels();
-    rawDecodingSettings.enableNoiseReduction       = d->decodingSettingsBox->useNoiseReduction();
-    rawDecodingSettings.brightness                 = d->decodingSettingsBox->brightness();
-    rawDecodingSettings.enableBlackPoint           = d->decodingSettingsBox->useBlackPoint();
-    rawDecodingSettings.blackPoint                 = d->decodingSettingsBox->blackPoint();
-    rawDecodingSettings.enableWhitePoint           = d->decodingSettingsBox->useWhitePoint();
-    rawDecodingSettings.whitePoint                 = d->decodingSettingsBox->whitePoint();
-    rawDecodingSettings.medianFilterPasses         = d->decodingSettingsBox->medianFilterPasses();
-    rawDecodingSettings.NRThreshold                = d->decodingSettingsBox->NRThreshold();
-    rawDecodingSettings.enableCACorrection         = d->decodingSettingsBox->useCACorrection();
-    rawDecodingSettings.caMultiplier[0]            = d->decodingSettingsBox->caRedMultiplier();
-    rawDecodingSettings.caMultiplier[1]            = d->decodingSettingsBox->caBlueMultiplier();
-    rawDecodingSettings.RAWQuality                 = d->decodingSettingsBox->quality();
-    rawDecodingSettings.outputColorSpace           = d->decodingSettingsBox->outputColorSpace();
-#if KDCRAW_VERSION >= 0x000500
-        rawDecodingSettings.autoBrightness         = d->decodingSettingsBox->useAutoBrightness();
-#endif
-
-    d->thread->setRawDecodingSettings(rawDecodingSettings, d->saveSettingsBox->fileFormat());
+    d->thread->setRawDecodingSettings(d->decodingSettingsBox->settings(), d->saveSettingsBox->fileFormat());
     d->thread->processRawFile(KUrl(d->inputFile));
     if (!d->thread->isRunning())
         d->thread->start();
