@@ -8,7 +8,7 @@
  *                SmugMug web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -23,7 +23,6 @@
  *
  * ============================================================ */
 
-#include "smugwindow.h"
 #include "smugwindow.moc"
 
 // Qt includes
@@ -31,12 +30,13 @@
 #include <QFileInfo>
 #include <QSpinBox>
 #include <QCheckBox>
+#include <QProgressBar>
 #include <QGroupBox>
 #include <QCloseEvent>
 
 // KDE includes
 
-#include <KDebug>
+#include <kdebug.h>
 #include <KConfig>
 #include <KLocale>
 #include <KMenu>
@@ -46,7 +46,6 @@
 #include <KMessageBox>
 #include <KPushButton>
 #include <KPasswordDialog>
-#include <KProgressDialog>
 #include <KToolInvocation>
 
 // LibKExiv2 includes
@@ -58,10 +57,6 @@
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
 
-#if KDCRAW_VERSION < 0x000400
-#include <libkdcraw/dcrawbinary.h>
-#endif
-
 // LibKIPI includes
 
 #include <libkipi/interface.h>
@@ -94,8 +89,8 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString& tmpFolder,
 
     setMainWidget(m_widget);
     setWindowIcon(KIcon("smugmug"));
-    setButtons(Help|User1|Close);
-    setDefaultButton(Close);
+    setButtons(Help|User1|Cancel);
+    setDefaultButton(Cancel);
     setModal(false);
 
     if (import)
@@ -128,9 +123,6 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString& tmpFolder,
     connect(m_widget->m_newAlbumBtn, SIGNAL( clicked() ),
             this, SLOT( slotNewAlbumRequest()) );
 
-    connect(this, SIGNAL( closeClicked() ),
-            this, SLOT( slotClose()) );
-
     connect(this, SIGNAL( user1Clicked() ),
             this, SLOT( slotStartTransfer()) );
 
@@ -263,14 +255,31 @@ void SmugWindow::closeEvent(QCloseEvent *e)
     e->accept();
 }
 
-void SmugWindow::slotClose()
+void SmugWindow::slotButtonClicked(int button)
 {
-    if (m_talker->loggedIn())
-        m_talker->logout();
-
-    writeSettings();
-    m_widget->imagesList()->listView()->clear();
-    done(Close);
+    switch (button)
+    {
+        case Cancel:
+            if (m_widget->progressBar()->isHidden())
+            {
+                writeSettings();
+                m_widget->imagesList()->listView()->clear();
+                done(Close);
+            }
+            else // cancel login/transfer
+            {
+                m_talker->cancel();
+                m_transferQueue.clear();
+                m_widget->m_imgList->processed(false);
+                m_widget->progressBar()->hide();
+            }
+            break;
+        case User1:
+            slotStartTransfer();
+            break;
+        default:
+             KDialog::slotButtonClicked(button);
+    }
 }
 
 void SmugWindow::reactivate()
@@ -281,14 +290,8 @@ void SmugWindow::reactivate()
 
 void SmugWindow::authenticate(const QString& email, const QString& password)
 {
-    m_authProgressDlg = new KProgressDialog(this, i18n("Authentication"));
-    m_authProgressDlg->setMinimumDuration(0);
-    m_authProgressDlg->setModal(true);
-    m_authProgressDlg->setAutoReset(true);
-    m_authProgressDlg->setAutoClose(true);
-
-    connect(m_authProgressDlg, SIGNAL( cancelClicked() ),
-            this, SLOT( slotLoginCancel() ));
+    m_widget->progressBar()->show();
+    m_widget->progressBar()->setFormat("");
 
     m_talker->login(email, password);
 }
@@ -317,6 +320,7 @@ void SmugWindow::readSettings()
 
     m_widget->m_dimensionSpB->setValue(grp.readEntry("Maximum Width", 1600));
     m_widget->m_imageQualitySpB->setValue(grp.readEntry("Image Quality", 85));
+
     if (m_import)
     {
         KConfigGroup dialogGroup = config.group("Smug Import Dialog");
@@ -355,21 +359,20 @@ void SmugWindow::writeSettings()
 
 void SmugWindow::slotLoginProgress(int step, int maxStep, const QString &label)
 {
-    if (!m_authProgressDlg)
-        return;
+    QProgressBar* progressBar = m_widget->progressBar();
 
     if (!label.isEmpty())
-        m_authProgressDlg->setLabelText(label);
+        progressBar->setFormat(label);
 
     if (maxStep > 0)
-        m_authProgressDlg->progressBar()->setMaximum(maxStep);
+        progressBar->setMaximum(maxStep);
 
-    m_authProgressDlg->progressBar()->setValue(step);
+    progressBar->setValue(step);
 }
 
 void SmugWindow::slotLoginDone(int errCode, const QString &errMsg)
 {
-    m_authProgressDlg->hide();
+    m_widget->progressBar()->hide();
 
     buttonStateChange(m_talker->loggedIn());
     SmugUser user = m_talker->getUser();
@@ -410,6 +413,7 @@ void SmugWindow::slotListAlbumsDone(int errCode, const QString &errMsg,
     }
 
     m_widget->m_albumsCoB->clear();
+
     for (int i = 0; i < albumsList.size(); ++i)
     {
         QString albumIcon;
@@ -448,15 +452,8 @@ void SmugWindow::slotListPhotosDone(int errCode, const QString &errMsg,
     m_imagesTotal = m_transferQueue.count();
     m_imagesCount = 0;
 
-    m_progressDlg = new KProgressDialog(this, i18n("Transfer Progress"));
-    m_progressDlg->setMinimumDuration(0);
-    m_progressDlg->setModal(true);
-    m_progressDlg->setAutoReset(true);
-    m_progressDlg->setAutoClose(true);
-    m_progressDlg->progressBar()->setFormat(i18n("%v / %m"));
-
-    connect(m_progressDlg, SIGNAL( cancelClicked() ),
-            this, SLOT( slotTransferCancel() ));
+    m_widget->progressBar()->setMaximum(m_imagesTotal);
+    m_widget->progressBar()->setValue(0);
 
     // start download with first photo in queue
     downloadNextPhoto();
@@ -497,7 +494,7 @@ void SmugWindow::slotListAlbumTmplDone(int errCode, const QString &errMsg,
     m_talker->listCategories();
 }
 
-void SmugWindow::slotListCategoriesDone(int errCode, const QString &errMsg,
+void SmugWindow::slotListCategoriesDone(int errCode, const QString& errMsg,
                                         const QList <SmugCategory>& categoriesList)
 {
     if (errCode != 0)
@@ -647,26 +644,26 @@ void SmugWindow::slotNewAlbumRequest()
     }
 }
 
-void SmugWindow::slotLoginCancel()
-{
-    m_talker->cancel();
-    m_authProgressDlg->hide();
-}
-
 void SmugWindow::slotStartTransfer()
 {
     kDebug() << "slotStartTransfer invoked";
 
     if (m_import)
     {
+        m_widget->progressBar()->setFormat(i18n("%v / %m"));
+        m_widget->progressBar()->setMaximum(0);
+        m_widget->progressBar()->setValue(0);
+        m_widget->progressBar()->show();
+
         // list photos of the album, then start download
         m_talker->listPhotos(m_widget->m_albumsCoB->itemData(
-                                  m_widget->m_albumsCoB->currentIndex()).toInt(),
+                             m_widget->m_albumsCoB->currentIndex()).toInt(),
                              m_widget->getAlbumPassword(),
                              m_widget->getSitePassword());
     }
     else
     {
+        m_widget->m_imgList->clearProcessedStatus();
         m_transferQueue = m_widget->m_imgList->imageUrls();
 
         if (m_transferQueue.isEmpty())
@@ -677,15 +674,10 @@ void SmugWindow::slotStartTransfer()
         m_imagesTotal = m_transferQueue.count();
         m_imagesCount = 0;
 
-        m_progressDlg = new KProgressDialog(this, i18n("Transfer Progress"));
-        m_progressDlg->setMinimumDuration(0);
-        m_progressDlg->setModal(true);
-        m_progressDlg->setAutoReset(true);
-        m_progressDlg->setAutoClose(true);
-        m_progressDlg->progressBar()->setFormat(i18n("%v / %m"));
-
-        connect(m_progressDlg, SIGNAL( cancelClicked() ),
-                this, SLOT( slotTransferCancel() ));
+        m_widget->progressBar()->setFormat(i18n("%v / %m"));
+        m_widget->progressBar()->setMaximum(m_imagesTotal);
+        m_widget->progressBar()->setValue(0);
+        m_widget->progressBar()->show();
 
         kDebug() << "m_currentAlbumID" << m_currentAlbumID;
         uploadNextPhoto();
@@ -742,21 +734,20 @@ void SmugWindow::uploadNextPhoto()
 {
     if (m_transferQueue.isEmpty())
     {
-        m_progressDlg->hide();
+        m_widget->progressBar()->hide();
         return;
     }
 
-    m_progressDlg->progressBar()->setMaximum(m_imagesTotal);
-    m_progressDlg->progressBar()->setValue(m_imagesCount);
+    m_widget->m_imgList->processing(m_transferQueue.first());
 
     QString imgPath = m_transferQueue.first().path();
+    KIPI::ImageInfo info(m_interface->info(imgPath));
+
+    m_widget->progressBar()->setMaximum(m_imagesTotal);
+    m_widget->progressBar()->setValue(m_imagesCount);
 
     // check if we have to RAW file -> use preview image then
-#if KDCRAW_VERSION < 0x000400
-    QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
-#else
     QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-#endif
     QFileInfo fileInfo(imgPath);
     bool isRAW = rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper());
     bool res;
@@ -768,12 +759,12 @@ void SmugWindow::uploadNextPhoto()
             slotAddPhotoDone(666, i18n("Cannot open file"));
             return;
         }
-        res = m_talker->addPhoto(m_tmpPath, m_currentAlbumID);
+        res = m_talker->addPhoto(m_tmpPath, m_currentAlbumID, info.description());
     }
     else
     {
         m_tmpPath.clear();
-        res = m_talker->addPhoto(imgPath, m_currentAlbumID);
+        res = m_talker->addPhoto(imgPath, m_currentAlbumID, info.description());
     }
 
     if (!res)
@@ -781,9 +772,6 @@ void SmugWindow::uploadNextPhoto()
         slotAddPhotoDone(666, i18n("Cannot open file"));
         return;
     }
-
-    m_progressDlg->setLabelText(i18n("Uploading file %1",
-                                     m_transferQueue.first().path()));
 }
 
 void SmugWindow::slotAddPhotoDone(int errCode, const QString& errMsg)
@@ -795,12 +783,11 @@ void SmugWindow::slotAddPhotoDone(int errCode, const QString& errMsg)
         m_tmpPath.clear();
     }
 
+    m_widget->m_imgList->processed(errCode == 0);
+
     if (errCode == 0)
     {
-        // Remove photo uploaded from the list
-        m_widget->m_imgList->removeItemByUrl(m_transferQueue.first());
         m_transferQueue.pop_front();
-
         m_imagesCount++;
     }
     else
@@ -810,8 +797,8 @@ void SmugWindow::slotAddPhotoDone(int errCode, const QString& errMsg)
                               "Do you want to continue?", errMsg))
                          != KMessageBox::Continue)
         {
+            m_widget->progressBar()->hide();
             m_transferQueue.clear();
-            m_progressDlg->hide();
             return;
         }
     }
@@ -823,18 +810,16 @@ void SmugWindow::downloadNextPhoto()
 {
     if (m_transferQueue.isEmpty())
     {
-        m_progressDlg->hide();
+        m_widget->progressBar()->hide();
         return;
     }
 
-    m_progressDlg->progressBar()->setMaximum(m_imagesTotal);
-    m_progressDlg->progressBar()->setValue(m_imagesCount);
+    m_widget->progressBar()->setMaximum(m_imagesTotal);
+    m_widget->progressBar()->setValue(m_imagesCount);
 
     QString imgPath = m_transferQueue.first().url();
 
     m_talker->getPhoto(imgPath);
-
-    m_progressDlg->setLabelText(i18n("Downloading file %1", imgPath));
 }
 
 void SmugWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
@@ -871,7 +856,7 @@ void SmugWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
                              != KMessageBox::Continue)
             {
                 m_transferQueue.clear();
-                m_progressDlg->hide();
+                m_widget->progressBar()->hide();
                 return;
             }
         }
@@ -884,7 +869,7 @@ void SmugWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
                          != KMessageBox::Continue)
         {
             m_transferQueue.clear();
-            m_progressDlg->hide();
+            m_widget->progressBar()->hide();
             return;
         }
     }
@@ -892,14 +877,6 @@ void SmugWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
     downloadNextPhoto();
 }
 
-void SmugWindow::slotTransferCancel()
-{
-    m_transferQueue.clear();
-    m_progressDlg->hide();
-
-    m_talker->cancel();
-}
-
 void SmugWindow::slotCreateAlbumDone(int errCode, const QString& errMsg,
                                      int newAlbumID)
 {
